@@ -4,7 +4,7 @@ ksubscribe
 An event-based programming methodology for Python coders!
 """
 
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 __author__ = 'Osman Onur KUZUCU'
 __credits__ = 'KZC Software Inc.'
 
@@ -65,4 +65,22 @@ class Ksubscribe(metaclass=KsubscribeSingletonMeta):
                 print("EventBasedFramework : Cannot subscribe an event. Because the event is not exist in event collections")
         except Exception as e:
             print("EventBasedFramework :",e)
+
+    def _removeAnEvent(self,eventName:str):
+        try:
+            if(self.__eventList.get(eventName) != None):
+                self.__eventList.pop(eventName)
+            else:
+                print("EventBasedFramework : Cannot subscribe an event. Because the event is not exist in event collections")
+        except Exception as e:
+            print("EventBasedFramework :",e)
+
+    def _removeAllEvents(self):
+        try:
+            if(len(self.__eventList)>0):
+                self.__eventList.clear()
+            else:
+                print("EventBasedFramework : Cannot subscribe an event. Because the event is not exist in event collections")
+        except Exception as e:
+            print("EventBasedFramework :",e)
     
